@@ -1,38 +1,39 @@
 import sys
 from .core import run, single_run, run_next, run_interrupted, single_run_interrupted, make_directories, copy_files, \
-    ani_to_fdf, xyz_to_fdf, merge_ani, analysis, log, cores, conda, contfiles
+    ani_to_fdf, xyz_to_fdf, merge_ani, analysis, energy_diff, contfiles, update_log, update_cores, update_conda, \
+    update_cont
 
 function = sys.argv[1]
 for arg in sys.argv:
     if arg.startswith("mpirun="):
-        cores = int(arg.split("=")[1])
+        update_cores(int(arg.split("=")[1]))
     if arg.startswith("conda="):
-        conda = arg.split("=")[1]
+        update_conda(arg.split("=")[1])
     if arg.startswith("cont="):
-        cont = arg.split("=")[1]
+        update_cont(arg.split("=")[1])
     if arg.startswith("contfiles="):
         contfiles.extend(arg.split("=")[1].split(","))
 
 if function not in ["run", "single_run", "run_next", "run_interrupted", "single_run_interrupted", "make_directories",
-                    "copy_files", "ani_to_fdf", "xyz_to_fdf", "merge_ani", "analysis"]:
+                    "copy_files", "ani_to_fdf", "xyz_to_fdf", "merge_ani", "analysis", "energy_diff"]:
     raise AttributeError(
         """Command not found. Please use 'run', 'single_run', 'run_next', 'run_interrupted', 'single_run_interrupted', 
-        'make_directories', 'copy_files', 'ani_to_fdf', 'xyz_to_fdf', 'merge_ani', 'analysis' """
+        'make_directories', 'copy_files', 'ani_to_fdf', 'xyz_to_fdf', 'merge_ani', 'analysis', 'energy_diff'"""
     )
 elif function == "run":
-    log = sys.argv[2]
+    update_log(sys.argv[2])
     run(sys.argv[3])
 elif function == "single_run":
-    log = sys.argv[2]
+    update_log(sys.argv[2])
     single_run(sys.argv[3], sys.argv[4])
 elif function == "run_next":
-    log = sys.argv[2]
+    update_log(sys.argv[2])
     run_next(sys.argv[3], sys.argv[4])
 elif function == "run_interrupted":
-    log = sys.argv[2]
+    update_log(sys.argv[2])
     run_interrupted(sys.argv[3], sys.argv[4])
 elif function == "single_run_interrupted":
-    log = sys.argv[2]
+    update_log(sys.argv[2])
     single_run_interrupted(sys.argv[3], sys.argv[4])
 elif function == "make_directories":
     make_directories(int(sys.argv[2]))
@@ -52,7 +53,7 @@ elif function == "merge_ani":
                 path = arg.split("=")[1]
         merge_ani(label=sys.argv[2], path=path)
 elif function == "analysis":
-    log = sys.argv[2]
+    update_log(sys.argv[2])
     plot_ = True
     path = "i*"
     if len(sys.argv) > 4:
@@ -64,3 +65,13 @@ elif function == "analysis":
         analysis(path=path, plot_=plot_)
     else:
         analysis()
+elif function == "energy_diff":
+    update_log(sys.argv[2])
+    path = "i*"
+    if len(sys.argv) > 4:
+        for arg in sys.argv[3:]:
+            if arg.startswith("path="):
+                path = arg.split("=")[1]
+        energy_diff(path=path)
+    else:
+        energy_diff()
